@@ -8,7 +8,7 @@
 # to do with audio, video, and animation what Wiki platforms allow them to do with
 # text.
 #
-# Copyright (C) 2006-2021  Kaltura Inc.
+# Copyright (C) 2006-2022  Kaltura Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -560,7 +560,7 @@ class KalturaVendorIntegrationService(KalturaServiceBase):
 
         kparams = KalturaParams()
         kparams.addIntIfDefined("id", id);
-        kparams.addObjectIfDefined("status", status)
+        kparams.addIntIfDefined("status", status);
         self.client.queueServiceActionCall("vendor_vendorintegration", "updateStatus", "KalturaIntegrationSetting", kparams)
         if self.client.isMultiRequest():
             return self.client.getMultiRequestResult()
